@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2019 KDE Developers 
+    SPDX-FileCopyrightText: 2019 KDE Developers
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,6 +9,7 @@
 
 #include <ktexteditor/configpage.h>
 
+class KFontRequester;
 class KUrlRequester;
 class QAbstractButton;
 class QAbstractSlider;
@@ -40,6 +41,7 @@ public:
     void observeChanges(QComboBox *comboBox);
     void observeChanges(QGroupBox *groupBox);
     void observeChanges(QLineEdit *lineEdit);
+    void observeChanges(KFontRequester *chooser);
 
 protected Q_SLOTS:
     void slotChanged();
