@@ -13,21 +13,8 @@
 // BEGIN INCLUDES
 #include "katehighlight.h"
 
-#include "kateconfig.h"
 #include "katedocument.h"
-#include "kateglobal.h"
-#include "katepartdebug.h"
-#include "katerenderer.h"
-
-#include <KConfig>
-#include <KConfigGroup>
-#include <KMessageBox>
-
-#include <QAction>
-#include <QApplication>
-#include <QSet>
-#include <QTextStream>
-#include <QVarLengthArray>
+#include "katesyntaxmanager.h"
 // END
 
 // BEGIN KateHighlighting
@@ -67,8 +54,9 @@ KateHighlighting::KateHighlighting(const KSyntaxHighlighting::Definition &def)
 
     embeddedHighlightingModes.reserve(definitions.size());
     // first: handle only really included definitions
-    for (const auto &includedDefinition : qAsConst(definitions))
+    for (const auto &includedDefinition : std::as_const(definitions)) {
         embeddedHighlightingModes.push_back(includedDefinition.name());
+    }
 
     // now: handle all, including this definition itself
     // create the format => attributes mapping
@@ -82,12 +70,13 @@ KateHighlighting::KateHighlighting(const KSyntaxHighlighting::Definition &def)
     definitions.push_front(definition());
     m_properties.resize(definitions.size());
     size_t propertiesIndex = 0;
-    for (const auto &includedDefinition : qAsConst(definitions)) {
+    for (const auto &includedDefinition : std::as_const(definitions)) {
         auto &properties = m_properties[propertiesIndex];
         properties.definition = includedDefinition;
         properties.emptyLines.reserve(includedDefinition.foldingIgnoreList().size());
-        for (const auto &emptyLine : includedDefinition.foldingIgnoreList())
-            properties.emptyLines.push_back(QRegularExpression(emptyLine));
+        for (const auto &emptyLine : includedDefinition.foldingIgnoreList()) {
+            properties.emptyLines.push_back(QRegularExpression(emptyLine, QRegularExpression::UseUnicodePropertiesOption));
+        }
         properties.singleLineCommentMarker = includedDefinition.singleLineCommentMarker();
         properties.singleLineCommentPosition = includedDefinition.singleLineCommentPosition();
         const auto multiLineComment = includedDefinition.multiLineCommentMarker();
@@ -115,7 +104,11 @@ KateHighlighting::KateHighlighting(const KSyntaxHighlighting::Definition &def)
     }
 }
 
-void KateHighlighting::doHighlight(const Kate::TextLineData *prevLine, Kate::TextLineData *textLine, const Kate::TextLineData *nextLine, bool &ctxChanged, int tabWidth)
+void KateHighlighting::doHighlight(const Kate::TextLineData *prevLine,
+                                   Kate::TextLineData *textLine,
+                                   const Kate::TextLineData *nextLine,
+                                   bool &ctxChanged,
+                                   int tabWidth)
 {
     // default: no context change
     ctxChanged = false;
@@ -167,7 +160,8 @@ void KateHighlighting::doHighlight(const Kate::TextLineData *prevLine, Kate::Tex
     // check for indentation based folding
     if (m_foldingIndentationSensitive && (tabWidth > 0) && !textLine->markedAsFoldingStartAttribute()) {
         // compute if we increase indentation in next line
-        if (endOfLineState.indentationBasedFoldingEnabled() && !isEmptyLine(textLine) && !isEmptyLine(nextLine) && (textLine->indentDepth(tabWidth) < nextLine->indentDepth(tabWidth))) {
+        if (endOfLineState.indentationBasedFoldingEnabled() && !isEmptyLine(textLine) && !isEmptyLine(nextLine)
+            && (textLine->indentDepth(tabWidth) < nextLine->indentDepth(tabWidth))) {
             textLine->markAsFoldingStartIndentation();
         }
     }
@@ -252,12 +246,14 @@ KTextEditor::DefaultStyle KateHighlighting::defaultStyleForAttribute(int attr) c
 QString KateHighlighting::nameForAttrib(int attrib) const
 {
     const auto &format = m_formats.at(sanitizeFormatIndex(attrib));
-    return m_propertiesForFormat.at(sanitizeFormatIndex(attrib))->definition.name() + QLatin1Char(':') + QString(format.isValid() ? format.name() : QStringLiteral("Normal"));
+    return m_propertiesForFormat.at(sanitizeFormatIndex(attrib))->definition.name() + QLatin1Char(':')
+        + QString(format.isValid() ? format.name() : QStringLiteral("Normal"));
 }
 
 bool KateHighlighting::isInWord(QChar c, int attrib) const
 {
-    return !m_propertiesForFormat.at(sanitizeFormatIndex(attrib))->definition.isWordDelimiter(c) && !c.isSpace() && c != QLatin1Char('"') && c != QLatin1Char('\'') && c != QLatin1Char('`');
+    return !m_propertiesForFormat.at(sanitizeFormatIndex(attrib))->definition.isWordDelimiter(c) && !c.isSpace() && c != QLatin1Char('"')
+        && c != QLatin1Char('\'') && c != QLatin1Char('`');
 }
 
 bool KateHighlighting::canBreakAt(QChar c, int attrib) const
@@ -274,7 +270,9 @@ bool KateHighlighting::canComment(int startAttrib, int endAttrib) const
 {
     const auto startProperties = m_propertiesForFormat.at(sanitizeFormatIndex(startAttrib));
     const auto endProperties = m_propertiesForFormat.at(sanitizeFormatIndex(endAttrib));
-    return (startProperties == endProperties && ((!startProperties->multiLineCommentStart.isEmpty() && !startProperties->multiLineCommentEnd.isEmpty()) || !startProperties->singleLineCommentMarker.isEmpty()));
+    return (startProperties == endProperties
+            && ((!startProperties->multiLineCommentStart.isEmpty() && !startProperties->multiLineCommentEnd.isEmpty())
+                || !startProperties->singleLineCommentMarker.isEmpty()));
 }
 
 QString KateHighlighting::getCommentStart(int attrib) const
@@ -319,21 +317,21 @@ QVector<KTextEditor::Attribute::Ptr> KateHighlighting::attributesForDefinition(c
         KTextEditor::Attribute::Ptr newAttribute(new KTextEditor::Attribute(nameForAttrib(array.size()), textStyleToDefaultStyle(format.textStyle())));
 
         if (const auto color = format.textColor(currentTheme).rgba()) {
-            newAttribute->setForeground(QColor(color));
+            newAttribute->setForeground(QColor::fromRgba(color));
         }
 
         if (const auto color = format.selectedTextColor(currentTheme).rgba()) {
-            newAttribute->setSelectedForeground(QColor(color));
+            newAttribute->setSelectedForeground(QColor::fromRgba(color));
         }
 
         if (const auto color = format.backgroundColor(currentTheme).rgba()) {
-            newAttribute->setBackground(QColor(color));
+            newAttribute->setBackground(QColor::fromRgba(color));
         } else {
             newAttribute->clearBackground();
         }
 
         if (const auto color = format.selectedBackgroundColor(currentTheme).rgba()) {
-            newAttribute->setSelectedBackground(QColor(color));
+            newAttribute->setSelectedBackground(QColor::fromRgba(color));
         } else {
             newAttribute->clearProperty(SelectedBackground);
         }
