@@ -21,10 +21,6 @@ KateUndo::KateUndo(KTextEditor::DocumentPrivate *document)
 {
 }
 
-KateUndo::~KateUndo()
-{
-}
-
 KateEditInsertTextUndo::KateEditInsertTextUndo(KTextEditor::DocumentPrivate *document, int line, int col, const QString &text)
     : KateUndo(document)
     , m_line(line)
@@ -344,7 +340,7 @@ void KateUndoGroup::safePoint(bool safePoint)
 
 void KateUndoGroup::flagSavedAsModified()
 {
-    for (KateUndo *item : qAsConst(m_items)) {
+    for (KateUndo *item : std::as_const(m_items)) {
         if (item->isFlagSet(KateUndo::UndoLine1Saved)) {
             item->unsetFlag(KateUndo::UndoLine1Saved);
             item->setFlag(KateUndo::UndoLine1Modified);
