@@ -25,7 +25,13 @@ class KateInlineNoteData
 {
 public:
     KateInlineNoteData() = default;
-    KateInlineNoteData(KTextEditor::InlineNoteProvider *provider, const KTextEditor::View *view, const KTextEditor::Cursor &position, int index, bool underMouse, const QFont &font, int lineHeight);
+    KateInlineNoteData(KTextEditor::InlineNoteProvider *provider,
+                       const KTextEditor::View *view,
+                       const KTextEditor::Cursor &position,
+                       int index,
+                       bool underMouse,
+                       const QFont &font,
+                       int lineHeight);
 
     KTextEditor::InlineNoteProvider *m_provider = nullptr;
     const KTextEditor::View *m_view = nullptr;
